==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/guz-KE.pl <==
{
  am_pm_abbreviated => [
    "Ma",
    "Mo"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "guz-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ctt",
    "Cmn",
    "Cmt",
    "Ars",
    "Icm",
    "Est",
    "Cpr"
  ],
  day_format_narrow => [
    "C",
    "C",
    "C",
    "A",
    "I",
    "E",
    "C"
  ],
  day_format_wide => [
    "Chumatato",
    "Chumaine",
    "Chumatano",
    "Aramisi",
    "Ichuma",
    "Esabato",
    "Chumapiri"
  ],
  day_stand_alone_abbreviated => [
    "Ctt",
    "Cmn",
    "Cmt",
    "Ars",
    "Icm",
    "Est",
    "Cpr"
  ],
  day_stand_alone_narrow => [
    "C",
    "C",
    "C",
    "A",
    "I",
    "E",
    "C"
  ],
  day_stand_alone_wide => [
    "Chumatato",
    "Chumaine",
    "Chumatano",
    "Aramisi",
    "Ichuma",
    "Esabato",
    "Chumapiri"
  ],
  era_abbreviated => [
    "YA",
    "YK"
  ],
  era_narrow => [
    "YA",
    "YK"
  ],
  era_wide => [
    "Yeso ataiborwa",
    "Yeso kaiboirwe"
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Gusii",
  month_format_abbreviated => [
    "Can",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Cul",
    "Agt",
    "Sep",
    "Okt",
    "Nob",
    "Dis"
  ],
  month_format_narrow => [
    "C",
    "F",
    "M",
    "A",
    "M",
    "J",
    "C",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Chanuari",
    "Feburari",
    "Machi",
    "Apiriri",
    "Mei",
    "Juni",
    "Chulai",
    "Agosti",
    "Septemba",
    "Okitoba",
    "Nobemba",
    "Disemba"
  ],
  month_stand_alone_abbreviated => [
    "Can",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Cul",
    "Agt",
    "Sep",
    "Okt",
    "Nob",
    "Dis"
  ],
  month_stand_alone_narrow => [
    "C",
    "F",
    "M",
    "A",
    "M",
    "J",
    "C",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Chanuari",
    "Feburari",
    "Machi",
    "Apiriri",
    "Mei",
    "Juni",
    "Chulai",
    "Agosti",
    "Septemba",
    "Okitoba",
    "Nobemba",
    "Disemba"
  ],
  name => "Gusii Kenya",
  native_language => "Ekegusii",
  native_name => "Ekegusii Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "E1",
    "E2",
    "E3",
    "E4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Erobo entang\N{U+2019}ani",
    "Erobo yakabere",
    "Erobo yagatato",
    "Erobo yakane"
  ],
  quarter_stand_alone_abbreviated => [
    "E1",
    "E2",
    "E3",
    "E4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Erobo entang\N{U+2019}ani",
    "Erobo yakabere",
    "Erobo yagatato",
    "Erobo yakane"
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/guz-KE.pl <==
{
  am_pm_abbreviated => [
    "Ma",
    "Mo",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "guz-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ctt",
    "Cmn",
    "Cmt",
    "Ars",
    "Icm",
    "Est",
    "Cpr",
  ],
  day_format_narrow => [
    "C",
    "C",
    "C",
    "A",
    "I",
    "E",
    "C",
  ],
  day_format_wide => [
    "Chumatato",
    "Chumaine",
    "Chumatano",
    "Aramisi",
    "Ichuma",
    "Esabato",
    "Chumapiri",
  ],
  day_stand_alone_abbreviated => [
    "Ctt",
    "Cmn",
    "Cmt",
    "Ars",
    "Icm",
    "Est",
    "Cpr",
  ],
  day_stand_alone_narrow => [
    "C",
    "C",
    "C",
    "A",
    "I",
    "E",
    "C",
  ],
  day_stand_alone_wide => [
    "Chumatato",
    "Chumaine",
    "Chumatano",
    "Aramisi",
    "Ichuma",
    "Esabato",
    "Chumapiri",
  ],
  era_abbreviated => [
    "YA",
    "YK",
  ],
  era_narrow => [
    "YA",
    "YK",
  ],
  era_wide => [
    "Yeso ataiborwa",
    "Yeso kaiboirwe",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Gusii",
  month_format_abbreviated => [
    "Can",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Cul",
    "Agt",
    "Sep",
    "Okt",
    "Nob",
    "Dis",
  ],
  month_format_narrow => [
    "C",
    "F",
    "M",
    "A",
    "M",
    "J",
    "C",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Chanuari",
    "Feburari",
    "Machi",
    "Apiriri",
    "Mei",
    "Juni",
    "Chulai",
    "Agosti",
    "Septemba",
    "Okitoba",
    "Nobemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Can",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Cul",
    "Agt",
    "Sep",
    "Okt",
    "Nob",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "C",
    "F",
    "M",
    "A",
    "M",
    "J",
    "C",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Chanuari",
    "Feburari",
    "Machi",
    "Apiriri",
    "Mei",
    "Juni",
    "Chulai",
    "Agosti",
    "Septemba",
    "Okitoba",
    "Nobemba",
    "Disemba",
  ],
  name => "Gusii Kenya",
  native_language => "Ekegusii",
  native_name => "Ekegusii Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "E1",
    "E2",
    "E3",
    "E4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Erobo entang\N{U+2019}ani",
    "Erobo yakabere",
    "Erobo yagatato",
    "Erobo yakane",
  ],
  quarter_stand_alone_abbreviated => [
    "E1",
    "E2",
    "E3",
    "E4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Erobo entang\N{U+2019}ani",
    "Erobo yakabere",
    "Erobo yagatato",
    "Erobo yakane",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
